package net.xinhuamm.xycloud.xinhuamm_xycloud;

import android.text.TextUtils;

import androidx.annotation.Keep;

import com.xinhuamm.client.ClientUtils;
import com.xinhuamm.client.auto.MD5Utils;
import com.xinhuamm.client.log.Logger;

import java.util.ArrayList;
import java.util.List;
import java.util.concurrent.TimeUnit;

import io.reactivex.rxjava3.android.schedulers.AndroidSchedulers;
import io.reactivex.rxjava3.annotations.NonNull;
import io.reactivex.rxjava3.core.Observable;
import io.reactivex.rxjava3.core.ObservableSource;
import io.reactivex.rxjava3.core.Observer;
import io.reactivex.rxjava3.disposables.Disposable;
import io.reactivex.rxjava3.functions.Function;
import io.reactivex.rxjava3.schedulers.Schedulers;
import okhttp3.OkHttpClient;
import okhttp3.logging.HttpLoggingInterceptor;
import retrofit2.Retrofit;
import retrofit2.adapter.rxjava3.RxJava3CallAdapterFactory;
import retrofit2.converter.gson.GsonConverterFactory;
import retrofit2.http.Body;
import retrofit2.http.POST;

/**
 * @author ming
 * @since 2023/3/21
 * for: 公有云免登接口
 */
public class XYCloudLoginUtil {
    private static Retrofit retrofit;

//    public static boolean judgeClientUrl(Context context, String url) {
//        if (ClientUtils.isClientUrl(url)) {
//            if (XYCloudManager.INSTANCE.isLogin()) {
//                XYCloudActivity.start(context, url);
//            } else {
//
//            }
//            return true;
//        }
//        return false;
//    }

    /**
     * 生态云免登接口请求
     */
    public static void autoLogin(String redirectUrl, AutoLoginCallback callback) {
        callback.callback(redirectUrl);

//        String userId = "", userMobile = "";
//        autoLogin("b2Z3eC8jCQgQei1vkghbvlOM3YKIcMvsOMiQWx50KI6iveQPaDcEunNp4FIN4j0H", userId, userMobile, redirectUrl, callback);
    }

    public static void autoLogin(String appSecret, String userId, String userMobile, String redirectUrl, AutoLoginCallback callback) {
        if (!ClientUtils.isClientUrl(redirectUrl) || TextUtils.isEmpty(redirectUrl)) {
            if (null != callback) {
                callback.callback(redirectUrl);
            }
            return;
        }
        Logger.setDebug(XYCloudManager.INSTANCE.getCloudDebug());
        AutoLoginParam param = new AutoLoginParam();
        param.setUserId(userId);
        param.setUserPhone(userMobile);
        param.setRedirectUrl(redirectUrl);
        param.setTimestamp(System.currentTimeMillis());
        if (redirectUrl.contains("h5-answer-config")) {
            param.setAppCode("dtk");
        } else {
            param.setAppCode("lottery");
        }
        Observable.just(param)
                .flatMap(new Function<AutoLoginParam, ObservableSource<AutoLoginData>>() {
                    @Override
                    public ObservableSource<AutoLoginData> apply(AutoLoginParam autoLoginParam) throws Throwable {

                        String apiSign = appSecret;
                        List<String> valueList = new ArrayList<>();
                        valueList.add(String.valueOf(autoLoginParam.getTimestamp()));
                        valueList.add(autoLoginParam.getAppCode());
                        valueList.add(autoLoginParam.getRedirectUrl());
                        valueList.add(autoLoginParam.getUserId());
                        valueList.add(autoLoginParam.getUserPhone());
                        valueList.add(apiSign);
                        String signature = encryptParams(valueList);
                        autoLoginParam.setSignature(signature);

                        if (null == retrofit) {
                            retrofit = new Retrofit.Builder().addConverterFactory(GsonConverterFactory.create())
                                    .addCallAdapterFactory(RxJava3CallAdapterFactory.create())
                                    .client(new OkHttpClient.Builder().callTimeout(10, TimeUnit.SECONDS)
                                            .connectTimeout(10, TimeUnit.SECONDS)
                                            .addInterceptor(new HttpLoggingInterceptor(Logger::info).setLevel(HttpLoggingInterceptor.Level.BODY))
                                            .build())
//                                    .baseUrl("https://wodexuancheng.media.xinhuamm.net/")
                                    .baseUrl("https://zhejiangshengrongmeizhongxin.testnewmedia.xinhuaapp.com/")
//                                    .baseUrl("https://www.testnewmedia.xinhuaapp.com/")
//                                            .baseUrl("https://www.media.xinhuamm.net/")
                                    .build();
                        }
                        return retrofit.create(LoginService.class).autoLogin(autoLoginParam);
                    }
                })
                .subscribeOn(Schedulers.io())
                .doOnSubscribe(disposable -> {

                })
                .subscribeOn(AndroidSchedulers.mainThread())
                .observeOn(AndroidSchedulers.mainThread())
                .doFinally(() -> {

                })
                .subscribe(new Observer<AutoLoginData>() {
                    @Override
                    public void onSubscribe(@NonNull Disposable d) {

                    }

                    @Override
                    public void onNext(@NonNull AutoLoginData loginTmyData) {
                        if (null != callback) {
                            if (null == loginTmyData) {
                                callback.callback(redirectUrl);
                            } else {
                                if ("200".equals(loginTmyData.getStatus()) && null != loginTmyData.getData() && !TextUtils.isEmpty(loginTmyData.getData()
                                        .getAppUrl())) {
                                    callback.callback(loginTmyData.getData().getAppUrl());
                                } else {
                                    callback.callback(redirectUrl);
                                }
                            }
                        }
                    }

                    @Override
                    public void onError(@NonNull Throwable e) {
                        e.printStackTrace();
                        if (null != callback) {
                            callback.callback(redirectUrl);
                        }
                    }

                    @Override
                    public void onComplete() {

                    }
                });
    }

    interface LoginService {

        @POST("auxiliaryapi/callback/wc-xyy/auto-login")
        Observable<AutoLoginData> autoLogin(@Body AutoLoginParam map);
    }

    public interface AutoLoginCallback {
        void callback(String loginUrl);
    }

    @Keep
    private class AutoLoginData {

        private String status;
        private String msg;
        private Data data;

        public String getStatus() {
            return status;
        }

        public void setStatus(String status) {
            this.status = status;
        }

        public String getMsg() {
            return msg;
        }

        public void setMsg(String msg) {
            this.msg = msg;
        }

        public Data getData() {
            return data;
        }

        public void setData(Data data) {
            this.data = data;
        }

        private class Data {
            private String appUrl;

            public String getAppUrl() {
                return appUrl;
            }

            public void setAppUrl(String appUrl) {
                this.appUrl = appUrl;
            }
        }
    }

    private static String encryptParams(List<String> params) {
//        if (!params.isEmpty()) {
//            Collections.sort(params);
//        }
        StringBuffer sb = new StringBuffer();
        for (String str : params) {
            sb.append(str);
        }
        String originParamStr = sb.toString();
        String encryptParamStr = MD5Utils.getMD5(originParamStr);
        return encryptParamStr;
    }

    @Keep
    private static class AutoLoginParam {
        private String appCode;
        private String userId;
        private String userPhone;
        private String redirectUrl;
        private long timestamp;
        private String signature;

        public String getAppCode() {
            return appCode;
        }

        public void setAppCode(String appCode) {
            this.appCode = appCode;
        }

        public String getUserId() {
            return userId;
        }

        public void setUserId(String userId) {
            this.userId = userId;
        }

        public String getUserPhone() {
            return userPhone;
        }

        public void setUserPhone(String userPhone) {
            this.userPhone = userPhone;
        }

        public long getTimestamp() {
            return timestamp;
        }

        public void setTimestamp(long timestamp) {
            this.timestamp = timestamp;
        }

        public String getRedirectUrl() {
            return redirectUrl;
        }

        public void setRedirectUrl(String redirectUrl) {
            this.redirectUrl = redirectUrl;
        }

        public String getSignature() {
            return signature;
        }

        public void setSignature(String signature) {
            this.signature = signature;
        }
    }
}
