package net.xinhuamm.xycloud.xinhuamm_xycloud

import android.app.Activity
import android.content.Context
import android.content.Intent
import com.xinhuamm.client.ClientUtils
import com.xinhuamm.client.bridge.O2OJsInterface
import com.xinhuamm.client.ui.activity.ScanActivity
import com.xinhuamm.zxing.ScanConfig
import io.flutter.Log
import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.embedding.engine.plugins.activity.ActivityAware
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result

/** XinhuammXycloudPlugin */
class XinhuammXycloudPlugin : FlutterPlugin, MethodCallHandler, ActivityAware {
    /// The MethodChannel that will the communication between Flutter and native Android
    ///
    /// This local reference serves to register the plugin with the Flutter Engine and unregister it
    /// when the Flutter Engine is detached from the Activity
    private lateinit var channel: MethodChannel
    private lateinit var context: Context
    private lateinit var activity: Activity
    private var activityResult: Result? = null

    override fun onAttachedToEngine(flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
        channel = MethodChannel(flutterPluginBinding.binaryMessenger, "xinhuamm_xycloud")
        channel.setMethodCallHandler(this)
        XYCloudManager.setMethodChannel(channel)// 设置MethodChannel，目的调用dart方法
        context = flutterPluginBinding.applicationContext
        val registry = flutterPluginBinding.platformViewRegistry
        registry.registerViewFactory(
            "XYCloudFlutterWebView", XYCloudWebViewFactory(flutterPluginBinding.binaryMessenger)
        )
    }

    override fun onMethodCall(call: MethodCall, result: Result) {
        when (call.method) {
            "setCloudGlobalConfig" -> {
                XYCloudManager.setCloudIsDebug(call.argument<Boolean>("isDebug") ?: false)
                XYCloudManager.setCloudThemeColor(call.argument<String>("themeColor") ?: "#f38242")
                XYCloudManager.setCloudUserAgent(
                    call.argument<String>("userAgent") ?: "xinhuamm DV/1"
                )
            }
            "openCloudPage" -> {
                XYCloudManager.openCloudActivity(activity, call.arguments.toString())
            }
            "openScanPage" -> {
                activityResult = result
                activity.startActivityForResult(
                    Intent(context, ScanActivity::class.java), O2OJsInterface.SCAN_REQUEST_CODE
                )
            }
            "handleScanResult" -> {
                val scanResult = call.arguments.toString()
                if (scanResult.startsWith("020")) {
                    val clientResult = ClientUtils.handleO2OClientScanResult(scanResult)
                    if (!clientResult.isNullOrEmpty()) {
                        result.success(true)
                        XYCloudManager.openCloudActivity(activity, clientResult)
                        return
                    }
                }
                result.success(false)
            }
            else -> {
                result.notImplemented()
            }
        }
    }

    override fun onDetachedFromEngine(binding: FlutterPlugin.FlutterPluginBinding) {
        channel.setMethodCallHandler(null)
    }

    override fun onAttachedToActivity(binding: ActivityPluginBinding) {
        activity = binding.activity
        binding.addActivityResultListener { requestCode, resultCode, data ->
            if (requestCode == O2OJsInterface.SCAN_REQUEST_CODE && resultCode == Activity.RESULT_OK) {
                val scanResult = data!!.getStringExtra(ScanConfig.KEY_RESULT)
                if (scanResult?.startsWith("020") == true) {
                    val clientResult = ClientUtils.handleO2OClientScanResult(scanResult)
                    if (!clientResult.isNullOrEmpty()) {
                        activityResult?.success("")
                        XYCloudManager.openCloudActivity(activity, clientResult)
                        return@addActivityResultListener true
                    }
                }
                activityResult?.success(scanResult)
            }
            return@addActivityResultListener false
        }
    }

    override fun onDetachedFromActivityForConfigChanges() {

    }

    override fun onReattachedToActivityForConfigChanges(binding: ActivityPluginBinding) {

    }

    override fun onDetachedFromActivity() {

    }

}
