#import "XinhuammXycloudPlugin.h"
#import "XYCloudManager.h"
#import <YYModel/YYModel.h>
#import "XYCloudPlatformViewFactory.h"
#import "XYCloudGlobalConfig.h"

/// 打开 Cloud page
NSString *const kOpenCloudPageMethodName = @"openCloudPage";
/// 全局配置
NSString *const kSetCloudGlobalConfigMethodName = @"setCloudGlobalConfig";
/// 用来判断用户是否登录/用户是否切换。返回："*"/""/null
NSString *const  kGetUserIdMethodName = @"getUserId";
/// 获取免登接口请求参数
NSString *const kGetLoginParamMethodName = @"getLoginParam";
/// 分享
NSString *const kShareMethodName = @"share";
///  登录
NSString *const kLoginMethodName = @"login";
/// 打开扫一扫
NSString *const kOpenScanPageMethodName = @"openScanPage";
/// 处理扫码结果
NSString *const kHandleScanResultMethodName = @"handleScanResult";


@interface XinhuammXycloudPlugin()<XYCloudManagerDelegate>

///  通信相关类
@property (nonatomic, strong) FlutterMethodChannel* channel;

@end

@implementation XinhuammXycloudPlugin

+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
    FlutterMethodChannel* channel = [FlutterMethodChannel methodChannelWithName:@"xinhuamm_xycloud"
                                                                binaryMessenger:[registrar messenger]];
    XinhuammXycloudPlugin* instance = [[XinhuammXycloudPlugin alloc] init];
    instance.channel = channel;
    [registrar addMethodCallDelegate:instance channel:channel];
    
    XYCloudPlatformViewFactory *factory = [[XYCloudPlatformViewFactory alloc] init];
    [registrar registerViewFactory:factory withId:@"XYCloudFlutterWebView"];
}

/// 监听Flutter端调用原生端事件
/// - Parameters:
///   - call: flutter事件参数包含方法名 method、方法参数arguments
///   - result: flutter端回调
- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
    if ([kSetCloudGlobalConfigMethodName isEqualToString:call.method]) {
        if ([call.arguments isKindOfClass:[NSDictionary class]]) {
            /// 全局配置
            NSDictionary *dict = call.arguments;
            XYCloudGlobalConfig *model = [XYCloudGlobalConfig yy_modelWithDictionary:dict];
            if (model.weixinSchemeUrl.length) {
                [XYCloudGlobalConfig shareInstance].weixinSchemeUrl = model.weixinSchemeUrl;
            }
            if (model.appUrlScheme.length) {
                [XYCloudGlobalConfig shareInstance].appUrlScheme = model.appUrlScheme;
            }
            if (model.themeColor.length) {
                [XYCloudGlobalConfig shareInstance].themeColor = model.themeColor;
            }
            if (model.userAgent.length) {
                [XYCloudGlobalConfig shareInstance].userAgent = model.userAgent;
            }
            if (model.navigationColor.length) {
                [XYCloudGlobalConfig shareInstance].navigationColor = model.navigationColor;
            }
            
        }
        result([@"iOS " stringByAppendingString:call.method]);
        return;
    }
    if ([kOpenCloudPageMethodName isEqualToString:call.method]) {
        XYCloudManager *manager = [XYCloudManager managerWithUrl:call.arguments];
        [manager enterO2OPageFromController:nil isPush:NO];
        result([@"iOS " stringByAppendingString:call.method]);
        return;
    }
    if ([kOpenScanPageMethodName isEqualToString:call.method]) {
        [XYO2OModule openScanPage:^(NSString * _Nonnull scanResult) {
            NSString *handleResult = [XYO2OModule getUrlStringWithScanResult:scanResult];
            dispatch_after(dispatch_time(DISPATCH_TIME_NOW, (int64_t)(0.25 * NSEC_PER_SEC)), dispatch_get_main_queue(), ^{
                XYCloudManager *manager = [XYCloudManager managerWithUrl:handleResult];
                [manager enterO2OPageFromController:nil isPush:NO];
            });
            result(scanResult);
        }];
        return;
    }
    if ([kHandleScanResultMethodName isEqualToString:call.method]) {
        NSString *arguments = [NSString stringWithFormat:@"%@",call.arguments];
        if ([arguments hasPrefix:@"020"]) {
            NSString *handleResult = [XYO2OModule getUrlStringWithScanResult:arguments];
            XYCloudManager *manager = [XYCloudManager managerWithUrl:handleResult];
            [manager enterO2OPageFromController:nil isPush:NO];
        }
        BOOL open = [arguments hasPrefix:@"020"] ? YES : NO;
        result(@(open));
        return;
    }
    if ([kGetUserIdMethodName isEqualToString:call.method]){
        result([@"iOS " stringByAppendingString:call.method]);
        return;
    }
    result(FlutterMethodNotImplemented);
}

#pragma mark -XYCloudManagerDelegate

- (void)getCloudTokenWith:(NSDictionary *)parameters block:(void (^)(NSDictionary *))block {
    
    [self invokeMethod:kGetLoginParamMethodName arguments:nil result:^(id  _Nullable result) {
        if (!result)  return;
        XYCloudGlobalConfig *model = [XYCloudGlobalConfig yy_modelWithDictionary:result];
        if (!model.appUserToken.length) return;
        [XYCloudGlobalConfig shareInstance].appUserToken = model.appUserToken;
        /// 测试数据
        NSMutableDictionary *data = [NSMutableDictionary dictionary];
        data[@"status"] = @"200";
        NSMutableDictionary *msg = [NSMutableDictionary dictionary];
        /// params 为token
        msg[@"params"] = model.appUserToken;
        data[@"msg"] = msg;
        block ? block(data) : nil;
    }];
}

- (void)getUserInfoWith:(NSDictionary *)parameters block:(void (^)(NSDictionary *))block {
    [self invokeMethod:kGetLoginParamMethodName arguments:nil result:^(id  _Nullable result) {
        if (!result)  return;
        XYCloudManager *model = [XYCloudManager yy_modelWithDictionary:result];
        NSMutableDictionary *data = [NSMutableDictionary dictionary];
        data[@"id"] = model.userId;
        data[@"name"] = @"";
        data[@"avatar"] = @"";
        data[@"phone"] = model.phone;
        block ? block(data) : nil;
    }];
}

- (void)shareWithParameter:(NSDictionary *)shareDic getPosterBlock:(void (^)(BOOL))getPosterBlock {
    [self invokeMethod:kShareMethodName arguments:shareDic result:nil];
}


#pragma mark -privite
///  原生端主动调用Flutter
/// - Parameters:
///   - method: 方法名
///   - arguments: 参数
///   - callback: 回调
- (void)invokeMethod:(NSString *)method arguments:(id)arguments result:(FlutterResult)callback {
    [self.channel invokeMethod:method arguments:arguments result:callback];
}


/// 登录
/// - Parameters:
///   - arguments: 参数
///   - callback: 回调结果
- (void)loginWithArguments:(id)arguments  result:(FlutterResult)callback {
    [self invokeMethod:kLoginMethodName arguments:arguments result:callback];
}
@end
