## 新移云Flutter SDK对接文档

> 对接时若遇到任何冲突及问题，请联系陈明军（电话：17858939680）

### SDK依赖

**pubspec.yaml** 文件中引入

```yaml
dependencies:
  flutter:
    sdk: flutter
  # 新增
  xinhuamm_xycloud: ^1.0.3
```

### 代码引用

```dart
import 'package:xinhuamm_xycloud/xinhuamm_xycloud.dart';

final _xinhuammXycloudPlugin = XinhuammXycloud();
```

### 全局配置

```dart
void setCloudGlobalConfig() {
  _xinhuammXycloudPlugin.setCloudGlobalConfig({
    "weixinSchemeUrl": "微信支付协议",
    "appUrlScheme": "支付宝支付协议",
    "userAgent": "xinhuamm",
    "themeColor": "#f38242",
    "showNavigationBar": false,
    "isDebug": false
  });
}
```

### 全局回调

```dart
void setCloudMethodCallHandler() {
  _xinhuammXycloudPlugin.setCloudMethodCallHandler((call) {
    if ("login" == call.method) {
      // 打开登录页面
      print("打开登录页");
    } else if ("getLoginParam" == call.method) {
      // 获取免登接口请求参数。返回：json字符串
      /* {
        "userId":"用户标识",
        "userPhone":"用户手机号",
        "otherKey":"value",
        } */
      print("获取免登信息");
      // return Future.value({
      //   "userId": "用户标识",
      //   "userPhone": "用户手机号",
      //   "otherKey": "value",
      // });
    } else if ("share" == call.method) {
      // 调用分享功能，call中带有分享参数:
      /* {
        "title":"分享标题",
        "description":"分享摘要",
        "imageUrl":"分享图片",
        "url":"分享链接",
        } */
      String title = call.arguments['title'];
      String description = call.arguments['description'];
      String imageUrl = call.arguments['imageUrl'];
      String url = call.arguments['url'];
      print("分享");
    }
    return Future.value(null);
  });
}
```

### 打开新移云页面

```dart
void openCloudPage() {
  _xinhuammXycloudPlugin.openCloudPage("新移云地址");
}
```

### 获取新移云页面

```dart
Widget getXYCloudFlutterWebView() {
  const String viewType = 'XYCloudFlutterWebView';
  const String url = '新移云地址';
  const Map<String, dynamic> creationParam = {'url': url};
  const MessageCodec creationParamsCodec = StandardMessageCodec();
  if (defaultTargetPlatform == TargetPlatform.android) {
    return const AndroidView(
      viewType: viewType,
      creationParams: creationParam,
      creationParamsCodec: creationParamsCodec,
    );
  } else if (defaultTargetPlatform == TargetPlatform.iOS) {
    return const UiKitView(
      viewType: viewType,
      creationParams: creationParam,
      creationParamsCodec: creationParamsCodec,
    );
  }
  return Container();
}
```

### 处理扫码结果

```dart
void handleScanResult(String scanResult) async {
  bool handled = await _xinhuammXycloudPlugin.handleScanResult(scanResult);
  if (handled) {
    print("sdk内部已处理，外部无需处理");
  } else {
    print("sdk内部未处理，外部需处理");
  }
}
```